# Signalfx Terraform Module

## Docker image

Signalfx Daemon and Signalfx sidecar work slightly differently in that the SignalFx agent collects metrics from the underlying instance and metric endpoint, Daemon works in the standard way by slurping metrics directly from the Docker socket. It does this by giving itself read only access to the socket by mounting the socket as a read only volume. 

To do this root permissions are required for the Daemon but not for the Sidecar, to build for ecs pass RUNUSER=root and Fargate pass RUNUSER=signalfx-agent.

```
git@git.steamhaus.co.uk:terraform-signalfx/steamhaus-signalfx-agent.git
https://github.com/steamhaus/tf_mod_signalfx_daemon.git
```

## Variable Injection


I've configured the runtime to set user by variable injection , untested so in the interim you can build for the specific ECS type

To build the image for ECS Daemon set user as RUNUSER=root

### Untested variable injection  
```
VARIABLE RUNUSER=[signalfx-agent , root]
```


### Fargate Sidecar agent 

To build the image for Fargate pass in the sigalfx-agent user 

```
docker build -t steamhaus-signalfx:latest -a RUNUSER=signalfx-agent
```

### Deploy
Deploy the Signalfx agent then deploy the docker image to the new repo.


#### To Do
In module create CodeBuild pipeline for SignalFx image deployment



# Terraform Module

Example resource block  

### Repository
Before the service is deployed an ECR repository needs to be created. 


```
module "signalfx_daemon" {
  source          = "git@git.steamhaus.co.uk:terraform-signalfx/signalfx_terraform_module.git"
  client          = "right-said"
  envname         = "fred"
  region          = "eu-west-1"
  cluster         =  aws_ecs_cluster.ecs.id
  tag             = "latest"
  signalfx_memory = "512"
  signalfx_cpu    = "256"
  signalfx_switch = "enabled/disabled"

  signalfx_api_token = "123456789abcdefghijklmnopqrstuvwxyz"

}
```


